==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketLifecycleRuleNoncurrentVersionExpirationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketLifecycleRuleNoncurrentVersionExpirationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property days Specifies the number of days noncurrent object versions expire.
 */
public data class BucketLifecycleRuleNoncurrentVersionExpirationArgs(
    public val days: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketLifecycleRuleNoncurrentVersionExpirationArgs> {
    override fun toJava(): com.pulumi.aws.s3.inputs.BucketLifecycleRuleNoncurrentVersionExpirationArgs =
        com.pulumi.aws.s3.inputs.BucketLifecycleRuleNoncurrentVersionExpirationArgs.builder()
            .days(days?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketLifecycleRuleNoncurrentVersionExpirationArgs].
 */
@PulumiTagMarker
public class BucketLifecycleRuleNoncurrentVersionExpirationArgsBuilder internal constructor() {
    private var days: Output<Int>? = null

    /**
     * @param value Specifies the number of days noncurrent object versions expire.
     */
    @JvmName("ytvovxvfxoltpigp")
    public suspend fun days(`value`: Output<Int>) {
        this.days = value
    }

    /**
     * @param value Specifies the number of days noncurrent object versions expire.
     */
    @JvmName("ygaoajntjykefyiw")
    public suspend fun days(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.days = mapped
    }

    internal fun build(): BucketLifecycleRuleNoncurrentVersionExpirationArgs =
        BucketLifecycleRuleNoncurrentVersionExpirationArgs(
            days = days,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketLifecycleRuleNoncurrentVersionExpirationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketLifecycleRuleNoncurrentVersionExpirationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property days Specifies the number of days noncurrent object versions expire.
 */
public data class BucketLifecycleRuleNoncurrentVersionExpirationArgs(
    public val days: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketLifecycleRuleNoncurrentVersionExpirationArgs> {
    override fun toJava(): com.pulumi.aws.s3.inputs.BucketLifecycleRuleNoncurrentVersionExpirationArgs = com.pulumi.aws.s3.inputs.BucketLifecycleRuleNoncurrentVersionExpirationArgs.builder()
        .days(days?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketLifecycleRuleNoncurrentVersionExpirationArgs].
 */
@PulumiTagMarker
public class BucketLifecycleRuleNoncurrentVersionExpirationArgsBuilder internal constructor() {
    private var days: Output<Int>? = null

    /**
     * @param value Specifies the number of days noncurrent object versions expire.
     */
    @JvmName("fhachowpiwtmqxvn")
    public suspend fun days(`value`: Output<Int>) {
        this.days = value
    }

    /**
     * @param value Specifies the number of days noncurrent object versions expire.
     */
    @JvmName("aslegohjfaujbjuq")
    public suspend fun days(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.days = mapped
    }

    internal fun build(): BucketLifecycleRuleNoncurrentVersionExpirationArgs =
        BucketLifecycleRuleNoncurrentVersionExpirationArgs(
            days = days,
        )
}
